@@ -181,5 +181,5 @@ class WeChat():
         img_url = f"https://qyapi.weixin.qq.com/cgi-bin/media/uploadimg?access_token={self.get_access_token()}"
         files = {'media': open(path, 'rb')}
         result = requests.post(img_url, files=files).json()
-        print(result)
+        # print(result)
         return result['url']
